Merlin - Moviebox Official
Description: These are the brand new adventures of Merlin, the legendary sorcerer as a young man, when he was just a servant to young Prince Arthur on the royal court of Camelot, who has soon become his best friend, and turned Arthur into a great king and a legend. all in Moviebox
Keywords: MovieBox

# Merlin

#### 2009

#### R

#### United Kingdom

#### Adventure

#### Drama

#### Fantasy

These are the brand new adventures of Merlin, the legendary sorcerer as a young man, when he was just a servant to young Prince Arthur on the royal court of Camelot, who has soon become his best friend, and turned Arthur into a great king and a legend.
More
7.9 /10
85853 people rated

#### Episodes

#### Top Cast

#### User Review

Top Cast(24)
John Hurt
The Dragon
John Hurt
Voice of the Dragon
Colin Morgan
Merlin
Bradley James
Arthur
Richard Wilson
Gaius
Angel Coulby
Gwen
Katie McGrath
Morgana
Anthony Head
Uther Pendragon
Rupert Young
Sir Leon
Eoin Macken
Sir Gwaine
Eoin Macken
Gwaine
Tom Hopper
Sir Percival
Tomiwa Edun
Sir Elyan
Tomiwa Edun
Elyan
Nathaniel Parker
Agravaine
Michael Cronin
Geoffrey of Monmouth
Emilia Fox
Morgause
Alexander Vlahos
Mordred
Santiago Cabrera
Lancelot
Michelle Ryan
Nimueh
Caroline Faber
Hunith
Jake Michie
Writer
Johnny Capps
Writer
Julian Jones
Writer

### User Review

#### VAsVAF

25/07/2025 16:57
so interesting

#### VFtPhE

18/07/2025 22:50
Melin full movie

#### Wilkin Brito

17/07/2025 17:12
merlin

#### Francis

06/07/2025 18:40
best

#### Official Lugged

30/06/2025 18:58
Amazing

#### Pherry Ghetrich

29/06/2025 02:44
nice

#### Isiaka Rokibat

21/06/2025 20:14
Merlin season 6 need too be updated

#### Paul Noah

20/06/2025 21:57
best series in the world

#### Gift Gold

13/06/2025 21:35
Merlin 6

#### Cissé Moustahpa

11/06/2025 20:39
Merlin saison 2 e3
Disclaimer: All videos and pictures on MovieBox are from the Internet, and their copyrights belong to the original creators. We only provide webpage services and do not store, record, or upload any content.

## Merlin

#### 2009

#### R

#### United Kingdom

#### Adventure

#### Drama

#### Fantasy

These are the brand new adventures of Merlin, the legendary sorcerer as a young man, when he was just a servant to young Prince Arthur on the royal court of Camelot, who has soon become his best friend, and turned Arthur into a great king and a legend.
More

#### 7.9 /10

85853 people rated

### Watch Free

### Share

Episodes
Top Cast
User Review
Episodes
Top Cast
User Review

## Episodes

FZM
loklok
Netflix
Plex
S01
S02
S03
S04
S05
01
02
03
04
05
06
07
08
09
10
11
12
13
Top Cast(24)
John Hurt
The Dragon
John Hurt
Voice of the Dragon
Colin Morgan
Merlin
Bradley James
Arthur
Richard Wilson
Gaius
Angel Coulby
Gwen
Katie McGrath
Morgana
Anthony Head
Uther Pendragon
Rupert Young
Sir Leon
Eoin Macken
Sir Gwaine
Eoin Macken
Gwaine
Tom Hopper
Sir Percival
Tomiwa Edun
Sir Elyan
Tomiwa Edun
Elyan
Nathaniel Parker
Agravaine
Michael Cronin
Geoffrey of Monmouth
Emilia Fox
Morgause
Alexander Vlahos
Mordred
Santiago Cabrera
Lancelot
Michelle Ryan
Nimueh
Caroline Faber
Hunith
Jake Michie
Writer
Johnny Capps
Writer
Julian Jones
Writer

### User Review

#### VAsVAF

25/07/2025 16:57
so interesting

#### VFtPhE

18/07/2025 22:50
Melin full movie

#### Wilkin Brito

17/07/2025 17:12
merlin

#### Francis

06/07/2025 18:40
best

#### Official Lugged

30/06/2025 18:58
Amazing

#### Pherry Ghetrich

29/06/2025 02:44
nice

#### Isiaka Rokibat

21/06/2025 20:14
Merlin season 6 need too be updated

#### Paul Noah

20/06/2025 21:57
best series in the world

#### Gift Gold

13/06/2025 21:35
Merlin 6

#### Cissé Moustahpa

11/06/2025 20:39
Merlin saison 2 e3